@@ -92,8 +92,8 @@ static void hadamard_col8x2_avx2(__m256i *in, int iter) {
   }
 }
 
-static void hadamard_8x8x2_avx2(const int16_t *src_diff, ptrdiff_t src_stride,
-                                int16_t *coeff) {
+void aom_hadamard_lp_8x8_dual_avx2(const int16_t *src_diff,
+                                   ptrdiff_t src_stride, int16_t *coeff) {
   __m256i src[8];
   src[0] = _mm256_loadu_si256((const __m256i *)src_diff);
   src[1] = _mm256_loadu_si256((const __m256i *)(src_diff += src_stride));
@@ -102,7 +102,7 @@ static void hadamard_8x8x2_avx2(const int16_t *src_diff, ptrdiff_t src_stride,
   src[4] = _mm256_loadu_si256((const __m256i *)(src_diff += src_stride));
   src[5] = _mm256_loadu_si256((const __m256i *)(src_diff += src_stride));
   src[6] = _mm256_loadu_si256((const __m256i *)(src_diff += src_stride));
-  src[7] = _mm256_loadu_si256((const __m256i *)(src_diff += src_stride));
+  src[7] = _mm256_loadu_si256((const __m256i *)(src_diff + src_stride));
 
   hadamard_col8x2_avx2(src, 0);
   hadamard_col8x2_avx2(src, 1);
@@ -141,7 +141,8 @@ static INLINE void hadamard_16x16_avx2(const int16_t *src_diff,
   int idx;
   for (idx = 0; idx < 2; ++idx) {
     const int16_t *src_ptr = src_diff + idx * 8 * src_stride;
-    hadamard_8x8x2_avx2(src_ptr, src_stride, t_coeff + (idx * 64 * 2));
+    aom_hadamard_lp_8x8_dual_avx2(src_ptr, src_stride,
+                                  t_coeff + (idx * 64 * 2));
   }
 
   for (idx = 0; idx < 64; idx += 16) {
@@ -186,7 +187,8 @@ void aom_hadamard_lp_16x16_avx2(const int16_t *src_diff, ptrdiff_t src_stride,
   int16_t *t_coeff = coeff;
   for (int idx = 0; idx < 2; ++idx) {
     const int16_t *src_ptr = src_diff + idx * 8 * src_stride;
-    hadamard_8x8x2_avx2(src_ptr, src_stride, t_coeff + (idx * 64 * 2));
+    aom_hadamard_lp_8x8_dual_avx2(src_ptr, src_stride,
+                                  t_coeff + (idx * 64 * 2));
   }
 
   for (int idx = 0; idx < 64; idx += 16) {
@@ -345,7 +347,7 @@ void aom_highbd_hadamard_8x8_avx2(const int16_t *src_diff, ptrdiff_t src_stride,
   src16[4] = _mm_loadu_si128((const __m128i *)(src_diff += src_stride));
   src16[5] = _mm_loadu_si128((const __m128i *)(src_diff += src_stride));
   src16[6] = _mm_loadu_si128((const __m128i *)(src_diff += src_stride));
-  src16[7] = _mm_loadu_si128((const __m128i *)(src_diff += src_stride));
+  src16[7] = _mm_loadu_si128((const __m128i *)(src_diff + src_stride));
 
   src32[0] = _mm256_cvtepi16_epi32(src16[0]);
   src32[1] = _mm256_cvtepi16_epi32(src16[1]);
@@ -502,3 +504,51 @@ int aom_satd_lp_avx2(const int16_t *coeff, int length) {
     return _mm_cvtsi128_si32(accum_128);
   }
 }
+
+static INLINE __m256i calc_avg_8x8_dual_avx2(const uint8_t *s, int p) {
+  const __m256i s0 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s)));
+  const __m256i s1 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + p)));
+  const __m256i s2 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 2 * p)));
+  const __m256i s3 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 3 * p)));
+  const __m256i sum0 =
+      _mm256_add_epi16(_mm256_add_epi16(s0, s1), _mm256_add_epi16(s2, s3));
+  const __m256i s4 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 4 * p)));
+  const __m256i s5 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 5 * p)));
+  const __m256i s6 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 6 * p)));
+  const __m256i s7 =
+      _mm256_cvtepu8_epi16(_mm_loadu_si128((const __m128i *)(s + 7 * p)));
+  const __m256i sum1 =
+      _mm256_add_epi16(_mm256_add_epi16(s4, s5), _mm256_add_epi16(s6, s7));
+
+  // The result of two 8x8 sub-blocks in 16x16 block.
+  return _mm256_add_epi16(sum0, sum1);
+}
+
+void aom_avg_8x8_quad_avx2(const uint8_t *s, int p, int x16_idx, int y16_idx,
+                           int *avg) {
+  // Process 1st and 2nd 8x8 sub-blocks in a 16x16 block.
+  const uint8_t *s_tmp = s + y16_idx * p + x16_idx;
+  __m256i result_0 = calc_avg_8x8_dual_avx2(s_tmp, p);
+
+  // Process 3rd and 4th 8x8 sub-blocks in a 16x16 block.
+  s_tmp = s + ((y16_idx + 8) * p) + x16_idx;
+  __m256i result_1 = calc_avg_8x8_dual_avx2(s_tmp, p);
+
+  const __m256i constant_32 = _mm256_set1_epi16(32);
+  result_0 = _mm256_hadd_epi16(result_0, result_1);
+  result_1 = _mm256_adds_epu16(result_0, _mm256_srli_si256(result_0, 4));
+  result_0 = _mm256_adds_epu16(result_1, _mm256_srli_si256(result_1, 2));
+  result_0 = _mm256_adds_epu16(result_0, constant_32);
+  result_0 = _mm256_srli_epi16(result_0, 6);
+  avg[0] = _mm_extract_epi16(_mm256_castsi256_si128(result_0), 0);
+  avg[1] = _mm_extract_epi16(_mm256_extracti128_si256(result_0, 1), 0);
+  avg[2] = _mm_extract_epi16(_mm256_castsi256_si128(result_0), 4);
+  avg[3] = _mm_extract_epi16(_mm256_extracti128_si256(result_0, 1), 4);
+}
