@@ -472,122 +472,133 @@ DECLARE_ALIGNED(32, static const uint8_t, filt4_global_avx2[32]) = {
     s[10] = s[11];                                                             \
   }
 
-#define DIST_WTD_CONVOLVE_HORIZONTAL_FILTER_8TAP                               \
-  for (i = 0; i < im_h; i += 2) {                                              \
-    __m256i data = _mm256_castsi128_si256(_mm_loadu_si128((__m128i *)src_h));  \
-    if (i + 1 < im_h)                                                          \
-      data = _mm256_inserti128_si256(                                          \
-          data, _mm_loadu_si128((__m128i *)(src_h + src_stride)), 1);          \
-    src_h += (src_stride << 1);                                                \
-    __m256i res = convolve_lowbd_x(data, coeffs_x, filt);                      \
-                                                                               \
-    res =                                                                      \
-        _mm256_sra_epi16(_mm256_add_epi16(res, round_const_h), round_shift_h); \
-                                                                               \
-    _mm256_store_si256((__m256i *)&im_block[i * im_stride], res);              \
-  }
+#define DIST_WTD_CONVOLVE_HORIZONTAL_FILTER_8TAP                        \
+  do {                                                                  \
+    for (i = 0; i < im_h; i += 2) {                                     \
+      __m256i data =                                                    \
+          _mm256_castsi128_si256(_mm_loadu_si128((__m128i *)src_h));    \
+      if (i + 1 < im_h)                                                 \
+        data = _mm256_inserti128_si256(                                 \
+            data, _mm_loadu_si128((__m128i *)(src_h + src_stride)), 1); \
+      src_h += (src_stride << 1);                                       \
+      __m256i res = convolve_lowbd_x(data, coeffs_x, filt);             \
+                                                                        \
+      res = _mm256_sra_epi16(_mm256_add_epi16(res, round_const_h),      \
+                             round_shift_h);                            \
+                                                                        \
+      _mm256_store_si256((__m256i *)&im_block[i * im_stride], res);     \
+    }                                                                   \
+  } while (0)
 
 #define DIST_WTD_CONVOLVE_VERTICAL_FILTER_8TAP                                 \
-  __m256i s[8];                                                                \
-  __m256i s0 = _mm256_loadu_si256((__m256i *)(im_block + 0 * im_stride));      \
-  __m256i s1 = _mm256_loadu_si256((__m256i *)(im_block + 1 * im_stride));      \
-  __m256i s2 = _mm256_loadu_si256((__m256i *)(im_block + 2 * im_stride));      \
-  __m256i s3 = _mm256_loadu_si256((__m256i *)(im_block + 3 * im_stride));      \
-  __m256i s4 = _mm256_loadu_si256((__m256i *)(im_block + 4 * im_stride));      \
-  __m256i s5 = _mm256_loadu_si256((__m256i *)(im_block + 5 * im_stride));      \
+  do {                                                                         \
+    __m256i s[8];                                                              \
+    __m256i s0 = _mm256_loadu_si256((__m256i *)(im_block + 0 * im_stride));    \
+    __m256i s1 = _mm256_loadu_si256((__m256i *)(im_block + 1 * im_stride));    \
+    __m256i s2 = _mm256_loadu_si256((__m256i *)(im_block + 2 * im_stride));    \
+    __m256i s3 = _mm256_loadu_si256((__m256i *)(im_block + 3 * im_stride));    \
+    __m256i s4 = _mm256_loadu_si256((__m256i *)(im_block + 4 * im_stride));    \
+    __m256i s5 = _mm256_loadu_si256((__m256i *)(im_block + 5 * im_stride));    \
                                                                                \
-  s[0] = _mm256_unpacklo_epi16(s0, s1);                                        \
-  s[1] = _mm256_unpacklo_epi16(s2, s3);                                        \
-  s[2] = _mm256_unpacklo_epi16(s4, s5);                                        \
+    s[0] = _mm256_unpacklo_epi16(s0, s1);                                      \
+    s[1] = _mm256_unpacklo_epi16(s2, s3);                                      \
+    s[2] = _mm256_unpacklo_epi16(s4, s5);                                      \
                                                                                \
-  s[4] = _mm256_unpackhi_epi16(s0, s1);                                        \
-  s[5] = _mm256_unpackhi_epi16(s2, s3);                                        \
-  s[6] = _mm256_unpackhi_epi16(s4, s5);                                        \
+    s[4] = _mm256_unpackhi_epi16(s0, s1);                                      \
+    s[5] = _mm256_unpackhi_epi16(s2, s3);                                      \
+    s[6] = _mm256_unpackhi_epi16(s4, s5);                                      \
                                                                                \
-  for (i = 0; i < h; i += 2) {                                                 \
-    const int16_t *data = &im_block[i * im_stride];                            \
+    for (i = 0; i < h; i += 2) {                                               \
+      const int16_t *data = &im_block[i * im_stride];                          \
                                                                                \
-    const __m256i s6 = _mm256_loadu_si256((__m256i *)(data + 6 * im_stride));  \
-    const __m256i s7 = _mm256_loadu_si256((__m256i *)(data + 7 * im_stride));  \
+      const __m256i s6 =                                                       \
+          _mm256_loadu_si256((__m256i *)(data + 6 * im_stride));               \
+      const __m256i s7 =                                                       \
+          _mm256_loadu_si256((__m256i *)(data + 7 * im_stride));               \
                                                                                \
-    s[3] = _mm256_unpacklo_epi16(s6, s7);                                      \
-    s[7] = _mm256_unpackhi_epi16(s6, s7);                                      \
+      s[3] = _mm256_unpacklo_epi16(s6, s7);                                    \
+      s[7] = _mm256_unpackhi_epi16(s6, s7);                                    \
                                                                                \
-    const __m256i res_a = convolve(s, coeffs_y);                               \
-    const __m256i res_a_round = _mm256_sra_epi32(                              \
-        _mm256_add_epi32(res_a, round_const_v), round_shift_v);                \
+      const __m256i res_a = convolve(s, coeffs_y);                             \
+      const __m256i res_a_round = _mm256_sra_epi32(                            \
+          _mm256_add_epi32(res_a, round_const_v), round_shift_v);              \
                                                                                \
-    if (w - j > 4) {                                                           \
-      const __m256i res_b = convolve(s + 4, coeffs_y);                         \
-      const __m256i res_b_round = _mm256_sra_epi32(                            \
-          _mm256_add_epi32(res_b, round_const_v), round_shift_v);              \
-      const __m256i res_16b = _mm256_packs_epi32(res_a_round, res_b_round);    \
-      const __m256i res_unsigned = _mm256_add_epi16(res_16b, offset_const);    \
+      if (w - j > 4) {                                                         \
+        const __m256i res_b = convolve(s + 4, coeffs_y);                       \
+        const __m256i res_b_round = _mm256_sra_epi32(                          \
+            _mm256_add_epi32(res_b, round_const_v), round_shift_v);            \
+        const __m256i res_16b = _mm256_packs_epi32(res_a_round, res_b_round);  \
+        const __m256i res_unsigned = _mm256_add_epi16(res_16b, offset_const);  \
                                                                                \
-      if (do_average) {                                                        \
-        const __m256i data_ref_0 = load_line2_avx2(                            \
-            &dst[i * dst_stride + j], &dst[i * dst_stride + j + dst_stride]);  \
-        const __m256i comp_avg_res =                                           \
-            comp_avg(&data_ref_0, &res_unsigned, &wt, use_dist_wtd_comp_avg);  \
+        if (do_average) {                                                      \
+          const __m256i data_ref_0 =                                           \
+              load_line2_avx2(&dst[i * dst_stride + j],                        \
+                              &dst[i * dst_stride + j + dst_stride]);          \
+          const __m256i comp_avg_res = comp_avg(&data_ref_0, &res_unsigned,    \
+                                                &wt, use_dist_wtd_comp_avg);   \
                                                                                \
-        const __m256i round_result = convolve_rounding(                        \
-            &comp_avg_res, &offset_const, &rounding_const, rounding_shift);    \
+          const __m256i round_result = convolve_rounding(                      \
+              &comp_avg_res, &offset_const, &rounding_const, rounding_shift);  \
                                                                                \
-        const __m256i res_8 = _mm256_packus_epi16(round_result, round_result); \
-        const __m128i res_0 = _mm256_castsi256_si128(res_8);                   \
-        const __m128i res_1 = _mm256_extracti128_si256(res_8, 1);              \
+          const __m256i res_8 =                                                \
+              _mm256_packus_epi16(round_result, round_result);                 \
+          const __m128i res_0 = _mm256_castsi256_si128(res_8);                 \
+          const __m128i res_1 = _mm256_extracti128_si256(res_8, 1);            \
                                                                                \
-        _mm_storel_epi64((__m128i *)(&dst0[i * dst_stride0 + j]), res_0);      \
-        _mm_storel_epi64(                                                      \
-            (__m128i *)((&dst0[i * dst_stride0 + j + dst_stride0])), res_1);   \
+          _mm_storel_epi64((__m128i *)(&dst0[i * dst_stride0 + j]), res_0);    \
+          _mm_storel_epi64(                                                    \
+              (__m128i *)((&dst0[i * dst_stride0 + j + dst_stride0])), res_1); \
+        } else {                                                               \
+          const __m128i res_0 = _mm256_castsi256_si128(res_unsigned);          \
+          _mm_store_si128((__m128i *)(&dst[i * dst_stride + j]), res_0);       \
+                                                                               \
+          const __m128i res_1 = _mm256_extracti128_si256(res_unsigned, 1);     \
+          _mm_store_si128((__m128i *)(&dst[i * dst_stride + j + dst_stride]),  \
+                          res_1);                                              \
+        }                                                                      \
       } else {                                                                 \
-        const __m128i res_0 = _mm256_castsi256_si128(res_unsigned);            \
-        _mm_store_si128((__m128i *)(&dst[i * dst_stride + j]), res_0);         \
+        const __m256i res_16b = _mm256_packs_epi32(res_a_round, res_a_round);  \
+        const __m256i res_unsigned = _mm256_add_epi16(res_16b, offset_const);  \
                                                                                \
-        const __m128i res_1 = _mm256_extracti128_si256(res_unsigned, 1);       \
-        _mm_store_si128((__m128i *)(&dst[i * dst_stride + j + dst_stride]),    \
-                        res_1);                                                \
+        if (do_average) {                                                      \
+          const __m256i data_ref_0 =                                           \
+              load_line2_avx2(&dst[i * dst_stride + j],                        \
+                              &dst[i * dst_stride + j + dst_stride]);          \
+                                                                               \
+          const __m256i comp_avg_res = comp_avg(&data_ref_0, &res_unsigned,    \
+                                                &wt, use_dist_wtd_comp_avg);   \
+                                                                               \
+          const __m256i round_result = convolve_rounding(                      \
+              &comp_avg_res, &offset_const, &rounding_const, rounding_shift);  \
+                                                                               \
+          const __m256i res_8 =                                                \
+              _mm256_packus_epi16(round_result, round_result);                 \
+          const __m128i res_0 = _mm256_castsi256_si128(res_8);                 \
+          const __m128i res_1 = _mm256_extracti128_si256(res_8, 1);            \
+                                                                               \
+          *(int *)(&dst0[i * dst_stride0 + j]) = _mm_cvtsi128_si32(res_0);     \
+          *(int *)(&dst0[i * dst_stride0 + j + dst_stride0]) =                 \
+              _mm_cvtsi128_si32(res_1);                                        \
+                                                                               \
+        } else {                                                               \
+          const __m128i res_0 = _mm256_castsi256_si128(res_unsigned);          \
+          _mm_store_si128((__m128i *)(&dst[i * dst_stride + j]), res_0);       \
+                                                                               \
+          const __m128i res_1 = _mm256_extracti128_si256(res_unsigned, 1);     \
+          _mm_store_si128((__m128i *)(&dst[i * dst_stride + j + dst_stride]),  \
+                          res_1);                                              \
+        }                                                                      \
       }                                                                        \
-    } else {                                                                   \
-      const __m256i res_16b = _mm256_packs_epi32(res_a_round, res_a_round);    \
-      const __m256i res_unsigned = _mm256_add_epi16(res_16b, offset_const);    \
                                                                                \
-      if (do_average) {                                                        \
-        const __m256i data_ref_0 = load_line2_avx2(                            \
-            &dst[i * dst_stride + j], &dst[i * dst_stride + j + dst_stride]);  \
+      s[0] = s[1];                                                             \
+      s[1] = s[2];                                                             \
+      s[2] = s[3];                                                             \
                                                                                \
-        const __m256i comp_avg_res =                                           \
-            comp_avg(&data_ref_0, &res_unsigned, &wt, use_dist_wtd_comp_avg);  \
-                                                                               \
-        const __m256i round_result = convolve_rounding(                        \
-            &comp_avg_res, &offset_const, &rounding_const, rounding_shift);    \
-                                                                               \
-        const __m256i res_8 = _mm256_packus_epi16(round_result, round_result); \
-        const __m128i res_0 = _mm256_castsi256_si128(res_8);                   \
-        const __m128i res_1 = _mm256_extracti128_si256(res_8, 1);              \
-                                                                               \
-        *(uint32_t *)(&dst0[i * dst_stride0 + j]) = _mm_cvtsi128_si32(res_0);  \
-        *(uint32_t *)(&dst0[i * dst_stride0 + j + dst_stride0]) =              \
-            _mm_cvtsi128_si32(res_1);                                          \
-                                                                               \
-      } else {                                                                 \
-        const __m128i res_0 = _mm256_castsi256_si128(res_unsigned);            \
-        _mm_store_si128((__m128i *)(&dst[i * dst_stride + j]), res_0);         \
-                                                                               \
-        const __m128i res_1 = _mm256_extracti128_si256(res_unsigned, 1);       \
-        _mm_store_si128((__m128i *)(&dst[i * dst_stride + j + dst_stride]),    \
-                        res_1);                                                \
-      }                                                                        \
+      s[4] = s[5];                                                             \
+      s[5] = s[6];                                                             \
+      s[6] = s[7];                                                             \
     }                                                                          \
-                                                                               \
-    s[0] = s[1];                                                               \
-    s[1] = s[2];                                                               \
-    s[2] = s[3];                                                               \
-                                                                               \
-    s[4] = s[5];                                                               \
-    s[5] = s[6];                                                               \
-    s[6] = s[7];                                                               \
-  }
+  } while (0)
 
 static INLINE void prepare_coeffs_lowbd(
     const InterpFilterParams *const filter_params, const int subpel_q4,
