@@ -22,9 +22,7 @@ struct ThreadData;
 typedef struct EncWorkerData {
   struct AV1_COMP *cpi;
   struct ThreadData *td;
-#if CONFIG_FRAME_PARALLEL_ENCODE
   struct ThreadData *original_td;
-#endif  // CONFIG_FRAME_PARALLEL_ENCODE
   int start;
   int thread_id;
 } EncWorkerData;
@@ -79,7 +77,7 @@ void av1_tf_mt_dealloc(AV1TemporalFilterSync *tf_sync);
 
 void av1_compute_num_workers_for_mt(AV1_COMP *cpi);
 
-int av1_get_max_num_workers(AV1_COMP *cpi);
+int av1_get_max_num_workers(const AV1_COMP *cpi);
 
 void av1_create_workers(AV1_PRIMARY *ppi, int num_workers);
 
@@ -114,15 +112,12 @@ void av1_write_tile_obu_mt(
 
 int av1_compute_num_enc_workers(AV1_COMP *cpi, int max_workers);
 
-#if CONFIG_FRAME_PARALLEL_ENCODE
 int av1_compute_num_fp_contexts(AV1_PRIMARY *ppi, AV1EncoderConfig *oxcf);
 
 int av1_check_fpmt_config(AV1_PRIMARY *const ppi, AV1EncoderConfig *const oxcf);
 
 int av1_compress_parallel_frames(AV1_PRIMARY *const ppi,
                                  AV1_COMP_DATA *const first_cpi_data);
-#endif
-
 #ifdef __cplusplus
 }  // extern "C"
 #endif
