@@ -110,7 +110,7 @@ static const arg_def_t *svc_args[] = {
   &error_resilient_arg, &output_obu_arg, NULL
 };
 
-#define zero(Dest) memset(&(Dest), 0, sizeof(Dest));
+#define zero(Dest) memset(&(Dest), 0, sizeof(Dest))
 
 static const char *exec_name;
 
@@ -226,6 +226,7 @@ static aom_codec_err_t parse_layer_options_from_string(
     return AOM_CODEC_INVALID_PARAM;
 
   input_string = malloc(strlen(input));
+  if (!input_string) die("Failed to allocate input string.");
   memcpy(input_string, input, strlen(input));
   if (input_string == NULL) return AOM_CODEC_MEM_ERROR;
   token = strtok(input_string, delim);  // NOLINT
@@ -265,6 +266,10 @@ static void parse_command_line(int argc, const char **argv_,
 
   // process command line options
   argv = argv_dup(argc - 1, argv_ + 1);
+  if (!argv) {
+    fprintf(stderr, "Error allocating argument list\n");
+    exit(EXIT_FAILURE);
+  }
   for (argi = argj = argv; (*argj = *argi); argi += arg.argv_step) {
     arg.argv_step = 1;
 
@@ -284,8 +289,8 @@ static void parse_command_line(int argc, const char **argv_,
       svc_params->number_temporal_layers = arg_parse_uint(&arg);
     } else if (arg_match(&arg, &speed_arg, argi)) {
       app_input->speed = arg_parse_uint(&arg);
-      if (app_input->speed > 9) {
-        aom_tools_warn("Mapping speed %d to speed 9.\n", app_input->speed);
+      if (app_input->speed > 10) {
+        aom_tools_warn("Mapping speed %d to speed 10.\n", app_input->speed);
       }
     } else if (arg_match(&arg, &aqmode_arg, argi)) {
       app_input->aq_mode = arg_parse_uint(&arg);
@@ -1000,7 +1005,7 @@ static void set_layer_pattern(
       if (enable_longterm_temporal_ref && layer_id->spatial_layer_id == 2 &&
           layering_mode == 8) {
         ref_frame_config->ref_idx[SVC_ALTREF_FRAME] = REF_FRAMES - 1;
-        ref_frame_config->reference[SVC_ALTREF_FRAME] = 1;
+        if (!is_key_frame) ref_frame_config->reference[SVC_ALTREF_FRAME] = 1;
         if (base_count % 10 == 0 && layer_id->temporal_layer_id == 0)
           ref_frame_config->refresh[REF_FRAMES - 1] = 1;
       }
@@ -1100,7 +1105,8 @@ int main(int argc, const char **argv) {
 
   struct RateControlMetrics rc;
   int64_t cx_time = 0;
-  int64_t cx_time_sl[3];  // max number of spatial layers.
+  int64_t cx_time_layer[AOM_MAX_LAYERS];  // max number of layers.
+  int frame_cnt_layer[AOM_MAX_LAYERS];
   double sum_bitrate = 0.0;
   double sum_bitrate2 = 0.0;
   double framerate = 30.0;
@@ -1252,8 +1258,8 @@ int main(int argc, const char **argv) {
   aom_codec_control(&codec, AOME_SET_CPUUSED, app_input.speed);
   aom_codec_control(&codec, AV1E_SET_AQ_MODE, app_input.aq_mode ? 3 : 0);
   aom_codec_control(&codec, AV1E_SET_GF_CBR_BOOST_PCT, 0);
-  aom_codec_control(&codec, AV1E_SET_ENABLE_CDEF, 2);
-  aom_codec_control(&codec, AV1E_SET_LOOPFILTER_CONTROL, 2);
+  aom_codec_control(&codec, AV1E_SET_ENABLE_CDEF, 1);
+  aom_codec_control(&codec, AV1E_SET_LOOPFILTER_CONTROL, 1);
   aom_codec_control(&codec, AV1E_SET_ENABLE_WARPED_MOTION, 0);
   aom_codec_control(&codec, AV1E_SET_ENABLE_OBMC, 0);
   aom_codec_control(&codec, AV1E_SET_ENABLE_GLOBAL_MOTION, 0);
@@ -1300,7 +1306,11 @@ int main(int argc, const char **argv) {
                       max_intra_size_pct);
   }
 
-  for (unsigned int slx = 0; slx < ss_number_layers; slx++) cx_time_sl[slx] = 0;
+  for (unsigned int lx = 0; lx < ts_number_layers * ss_number_layers; lx++) {
+    cx_time_layer[lx] = 0;
+    frame_cnt_layer[lx] = 0;
+  }
+
   frame_avail = 1;
   while (frame_avail || got_data) {
     struct aom_usec_timer timer;
@@ -1374,7 +1384,8 @@ int main(int argc, const char **argv) {
         die_codec(&codec, "Failed to encode frame");
       aom_usec_timer_mark(&timer);
       cx_time += aom_usec_timer_elapsed(&timer);
-      cx_time_sl[slx] += aom_usec_timer_elapsed(&timer);
+      cx_time_layer[layer] += aom_usec_timer_elapsed(&timer);
+      frame_cnt_layer[layer] += 1;
 
       got_data = 0;
       while ((pkt = aom_codec_get_cx_data(&codec, &iter))) {
@@ -1475,19 +1486,22 @@ int main(int argc, const char **argv) {
   close_input_file(&(app_input.input_ctx));
   printout_rate_control_summary(&rc, frame_cnt, ss_number_layers,
                                 ts_number_layers);
+
+  printf("\n");
+  for (unsigned int slx = 0; slx < ss_number_layers; slx++)
+    for (unsigned int tlx = 0; tlx < ts_number_layers; tlx++) {
+      int lx = slx * ts_number_layers + tlx;
+      printf("Per layer encoding time/FPS stats for encoder: %d %d %d %f %f \n",
+             slx, tlx, frame_cnt_layer[lx],
+             (float)cx_time_layer[lx] / (double)(frame_cnt_layer[lx] * 1000),
+             1000000 * (double)frame_cnt_layer[lx] / (double)cx_time_layer[lx]);
+    }
+
   printf("\n");
   printf("Frame cnt and encoding time/FPS stats for encoding: %d %f %f\n",
          frame_cnt, 1000 * (float)cx_time / (double)(frame_cnt * 1000000),
          1000000 * (double)frame_cnt / (double)cx_time);
 
-  if (ss_number_layers > 1) {
-    printf("Per spatial layer: \n");
-    for (unsigned int slx = 0; slx < ss_number_layers; slx++)
-      printf("Frame cnt and encoding time/FPS stats for encoding: %d %f %f\n",
-             frame_cnt, (float)cx_time_sl[slx] / (double)(frame_cnt * 1000),
-             1000000 * (double)frame_cnt / (double)cx_time_sl[slx]);
-  }
-
   if (aom_codec_destroy(&codec)) die_codec(&codec, "Failed to destroy codec");
 
 #if CONFIG_INTERNAL_STATS
